all.Vansm<-function(){
     cat("\n")
     note_for_Vansm_input()
     cat("\n")
     note_for_close_window()
     VanSMMpar<-data.frame(parameter=c("Gender","age (yr)","bw (kg)","Scr (mg/dL)","D (mg)","tau (hr)","tin (hr)"),value=c(0))
     VanSMMpar<-edit(VanSMMpar)
##     VanSMMpar<-ycheck(VanSMMpar)
     cat("\n")
     note_for_Vansm_conc_input()
     cat("\n")
     note_for_close_window()
     VanSMpar<-data.frame(ts=c(0),conc=c(0))
     VanSMpar<-edit(VanSMpar)
     VanSMpar<-mscheck(VanSMpar)
     cat("\n")
     Van.sm(length(VanSMpar$ts),VanSMpar$conc,VanSMpar$ts,VanSMMpar[6,2],VanSMMpar[7,2],VanSMMpar[5,2],VanSMMpar[3,2],VanSMMpar[4,2],VanSMMpar[1,2],VanSMMpar[2,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Vansm_output()
     show(samplesStats("*"))
     cat("\n")
     C<-infcpr(VanSMMpar[5,2],VanSMMpar[7,2],VanSMMpar[6,2],VanSMMpar[6,2])/(exp(-(samplesStats("cl")/samplesStats("v"))*(VanSMMpar[6,2]-(VanSMMpar[7,2]+1))))
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-infcpr(VanSMMpar[5,2],VanSMMpar[7,2],VanSMMpar[6,2],VanSMMpar[6,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)     
     cat("\n")
     Van.more()
}